@@ -1,7 +1,7 @@
 /*
  *  eventlistview.cpp  -  base class for widget showing list of alarms
  *  Program:  kalarm
- *  Copyright © 2007-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2007-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,6 +44,15 @@ EventListView::EventListView(QWidget* parent)
     setWhatsThis(i18nc("@info:whatsthis", "List of scheduled alarms"));
 }
 
+void EventListView::setModel(QAbstractItemModel* model)
+{
+    EventListModel* elm = qobject_cast<EventListModel*>(model);
+    Q_ASSERT(elm);   // model must be derived from EventListModel
+
+    QTreeView::setModel(model);
+    connect(elm, &EventListModel::haveEventsStatus, this, &EventListView::initSections);
+}
+
 /******************************************************************************
 * Return the source data model.
 */
@@ -146,6 +155,12 @@ void EventListView::findNext(bool forward)
         mFind->findNext(forward);
 }
 
+void EventListView::resizeEvent(QResizeEvent* se)
+{
+    QTreeView::resizeEvent(se);
+    initSections();
+}
+
 /******************************************************************************
 * Called when a ToolTip or WhatsThis event occurs.
 */
