@@ -24,34 +24,36 @@
 #include "functions.h"
 #include "kalarmapp.h"
 #include "mainwindow.h"
-#include "messagebox.h"
 #include "preferences.h"
+#include "lib/messagebox.h"
 #include "kalarm_debug.h"
 
 #include "kmailinterface.h"
 
-#include <kalarmcal/identities.h>
-#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
-#include <KIdentityManagement/kidentitymanagement/identity.h>
-#include <mailtransport/transportmanager.h>
-#include <mailtransport/transport.h>
-#include <mailtransportakonadi/messagequeuejob.h>
+#include <KAlarmCal/Identities>
+
+#include <KIdentityManagement/IdentityManager>
+#include <KIdentityManagement/Identity>
+#include <MailTransport/TransportManager>
+#include <MailTransport/Transport>
+#include <MailTransportAkonadi/MessageQueueJob>
 #include <KCalendarCore/Person>
-#include <kmime/kmime_header_parsing.h>
-#include <kmime/kmime_headers.h>
-#include <kmime/kmime_message.h>
+#include <KMime/HeaderParsing>
+#include <KMime/Headers>
+#include <KMime/Message>
+#include <kio_version.h>
 
 #include <KEmailAddress>
 #include <KAboutData>
 #include <KLocalizedString>
-#include <kfileitem.h>
+#include <KFileItem>
 #include <KIO/StatJob>
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
-#include <kemailsettings.h>
-#include <kcodecs.h>
-#include <kcharsets.h>
-#include <kshell.h>
+#include <KEMailSettings>
+#include <KCodecs>
+#include <KCharsets>
+#include <KShell>
 
 #include <QUrl>
 #include <QFile>
@@ -148,7 +150,7 @@ int KAMail::send(JobData& jobdata, QStringList& errmsgs)
     }
     jobdata.bcc  = (jobdata.event.emailBcc() ? Preferences::emailBccAddress() : QString());
     qCDebug(KALARM_LOG) << "KAMail::send: To:" << jobdata.event.emailAddresses(QStringLiteral(","))
-                        << endl << "Subject:" << jobdata.event.emailSubject();
+                        << "\nSubject:" << jobdata.event.emailSubject();
 
     KMime::Message::Ptr message = KMime::Message::Ptr(new KMime::Message);
 
@@ -402,8 +404,11 @@ QString KAMail::appendBodyAttachments(KMime::Message& message, JobData& data)
             bool atterror = false;
             if (!url.isLocalFile())
             {
-                KIO::UDSEntry uds;
+#if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
                 auto statJob = KIO::stat(url, KIO::StatJob::SourceSide, 2);
+#else
+                auto statJob = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatDetail::StatDefaultDetails);
+#endif
                 KJobWidgets::setWindow(statJob, MainWindow::mainMainWindow());
                 if (!statJob->exec())
                 {
