@@ -1,7 +1,7 @@
 /*
  *  akonadiresource.h  -  class for an Akonadi alarm calendar resource
  *  Program:  kalarm
- *  Copyright © 2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2019-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,12 +23,16 @@
 
 #include "resource.h"
 
-#include <kalarmcal/collectionattribute.h>
+#include "kalarm_debug.h"
 
+#include <KAlarmCal/CollectionAttribute>
+
+#include <AkonadiCore/AgentInstance>
 #include <AkonadiCore/Collection>
 #include <AkonadiCore/Item>
 
 #include <QObject>
+#include <QDBusConnection>
 
 class KJob;
 class DuplicateResourceObject;
@@ -134,11 +138,11 @@ public:
     using ResourceType::isWritable;
 
     /** Return whether the user has chosen not to update the resource's
-     *  calendar storage formst. */
+     *  calendar storage format. */
     bool keepFormat() const override;
 
     /** Set or clear whether the user has chosen not to update the resource's
-     *  calendar storage formst. */
+     *  calendar storage format. */
     void setKeepFormat(bool keep) override;
 
     /** Return the background colour used to display alarms belonging to
@@ -209,8 +213,9 @@ public:
      *  current KAlarm format, in which case it cannot be written to.
      *  Note that isWritable() takes account of incompatible format
      *  as well as read-only and enabled statuses.
+     *  @param versionString  Receives calendar's KAlarm version as a string.
      */
-    KACalendar::Compat compatibility() const override;
+    KACalendar::Compat compatibilityVersion(QString& versionString) const override;
 
     /** Edit the resource's configuration. */
     void editResource(QWidget* dialogParent) override;
@@ -228,20 +233,18 @@ public:
      */
     bool load(bool readThroughCache = true) override;
 
-#if 0
     /** Reload the resource. Any cached data is first discarded. */
     bool reload() override;
-#endif
 
     /** Return whether the resource has fully loaded. */
     bool isPopulated() const override;
 
     /** Save the resource.
-     *  Not applicable to AkonadiResource, since AkonadiModel handles saving
+     *  Not applicable to AkonadiResource, since AkonadiDataModel handles saving
      *  automatically.
      *  @return true.
      */
-    bool save(bool writeThroughCache = true) override;
+    bool save(bool writeThroughCache = true, bool force = false) override;
 
     /** Add an event to the resource, and add it to Akonadi. */
     bool addEvent(const KAEvent&) override;
@@ -264,8 +267,8 @@ public:
 
     /******************************************************************************
     * Return a reference to the Collection held by an Akonadi resource.
-    * @reply Reference to the Collection, which belongs to AkonadiModel and whose
-    *        ID must not be changed.
+    * @reply Reference to the Collection, which belongs to AkonadiDataModel and
+    *        whose ID must not be changed.
     */
     static Akonadi::Collection& collection(Resource&);
     static const Akonadi::Collection& collection(const Resource&);
@@ -275,17 +278,6 @@ public:
     static KAEvent event(Resource&, const Akonadi::Item&);
     using QObject::event;   // prevent warning about hidden virtual method
 
-    /** Find the collection to be used to store an event of a given type.
-     *  This will be the standard collection for the type, but if this is not valid,
-     *  the user will be prompted to select a collection.
-     *  @param type         The event type
-     *  @param promptParent The parent widget for the prompt
-     *  @param noPrompt     Don't prompt the user even if the standard collection is not valid
-     *  @param cancelled    If non-null: set to true if the user cancelled the
-     *                      prompt dialogue; set to false if any other error
-     */
-    static Resource destination(CalEvent::Type type, QWidget* promptParent = nullptr, bool noPrompt = false, bool* cancelled = nullptr);
-
     /** Check for, and remove, Akonadi resources which duplicate use of
      *  calendar files/directories.
      */
@@ -313,6 +305,18 @@ public:
      */
     static void notifyItemChanged(Resource&, const Akonadi::Item&, bool created);
 
+    /** Create a D-Bus interface to an Akonadi resource.
+     *  @return  If success: interface;
+     *           If error: null, with 'errorMessage' containing the error message.
+     */
+    template <class Interface>
+    static Interface* getAgentInterface(const Akonadi::AgentInstance& agent, QString& errorMessage, QObject* parent);
+
+    /** The resource type for a single file Akonadi resource. */
+    static const QString KALARM_RESOURCE;
+    /** The resource type for a directory Akonadi resource. */
+    static const QString KALARM_DIR_RESOURCE;
+
 private Q_SLOTS:
     void slotCollectionRemoved(const Akonadi::Collection&);
     void itemJobDone(KJob*);
@@ -331,13 +335,37 @@ private:
     QHash<Akonadi::Item::Id, Akonadi::Item> mItemModifyJobQueue; // pending item modification jobs, invalid item = queue empty but job active
     QList<Akonadi::Item::Id>    mItemsBeingCreated;    // new items not fully initialised yet
     bool                        mValid;                // whether the collection is valid and belongs to an Akonadi resource
-    mutable bool                mHaveCollectionAttribute{false};  // whether the collection has a CollectionAttribute
-    bool                        mHaveCompatibilityAttribute{false};  // whether the collection has a CompatibilityAttribute
-    CalEvent::Types             mLastEnabled{CalEvent::EMPTY};  // last known enabled status
-    mutable bool                mNewEnabled{false};
-    bool                        mCollectionAttrChecked{false};  // CollectionAttribute has been processed first time
+    mutable bool                mHaveCollectionAttribute {false};  // whether the collection has a CollectionAttribute
+    bool                        mHaveCompatibilityAttribute {false};  // whether the collection has a CompatibilityAttribute
+    CalEvent::Types             mLastEnabled {CalEvent::EMPTY};  // last known enabled status
+    mutable bool                mNewEnabled {false};
+    bool                        mCollectionAttrChecked {false};  // CollectionAttribute has been processed first time
 };
 
+
+/*=============================================================================
+* Template definitions.
+*============================================================================*/
+
+/******************************************************************************
+* Create a D-Bus interface to an Akonadi resource.
+* Reply = interface if success
+*       = 0 if error: 'errorMessage' contains the error message.
+*/
+template <class Interface> Interface* AkonadiResource::getAgentInterface(const Akonadi::AgentInstance& agent, QString& errorMessage, QObject* parent)
+{
+    Interface* iface = new Interface(QLatin1String("org.freedesktop.Akonadi.Resource.") + agent.identifier(),
+              QStringLiteral("/Settings"), QDBusConnection::sessionBus(), parent);
+    if (!iface->isValid())
+    {
+        errorMessage = iface->lastError().message();
+        qCDebug(KALARM_LOG) << "AkonadiResource::getAgentInterface: D-Bus error accessing resource:" << errorMessage;
+        delete iface;
+        return nullptr;
+    }
+    return iface;
+}
+
 #endif // AKONADIRESOURCE_H
 
 // vim: et sw=4:
