@@ -24,9 +24,9 @@
 #include "functions.h"
 #include "kalarm_debug.h"
 
-#include <kalarmcal/kaevent.h>
+#include <KAlarmCal/KAEvent>
 
-#include <kactionmenu.h>
+#include <KActionMenu>
 #include <QMenu>
 
 
